# -*- coding: utf-8 -*-
import json

from django.contrib import messages
from django.http import HttpResponse


class JsonResponseMixin(object):
    def render_json(self, data, status=200, encoder=None):
        kwargs = {
            'ensure_ascii': False
        }
        if encoder:
            kwargs['cls'] = encoder

        return HttpResponse(json.dumps(data, **kwargs),
            content_type='application/json; charset=UTF-8',
            status=status)


class GenericEditJsonResponseMixin(object):
    """Adds support for ajax response in Django's generic edit views.

    This should be used with "django.views.generic.edit" views.
    """
    def render_to_json_response(self, context, **response_kwargs):
        data = json.dumps(context)
        response_kwargs['content_type'] = 'application/json; charset=UTF-8'
        return HttpResponse(data, **response_kwargs)

    def form_invalid(self, form):
        response = super(GenericEditJsonResponseMixin, self).form_invalid(form)
        if self.request.is_ajax():
            return self.render_to_json_response(form.errors, status=400)
        return response

    def form_valid(self, form):
        response = super(GenericEditJsonResponseMixin, self).form_valid(form)
        if self.request.is_ajax():
            return self.render_to_json_response({
                'pk': self.object.pk,
            })
        return response


class JsonMessagesMixin(object):
    """Adds support for adding messages as json data."""
    def set_message(self, type, title, content):
        jsonMessage = json.dumps({'title': title, 'content': content})
        messages.add_message(self.request, type, jsonMessage)

    def set_json_info_message(self, title, content):
        self.set_message(messages.INFO, title, content)

    def set_json_success_message(self, title, content):
        self.set_message(messages.SUCCESS, title, content)

    def set_json_error_message(self, title, content):
        self.set_message(messages.ERROR, title, content)



# -*- coding: utf-8 -*-
from django.views.generic.base import TemplateView


class BaseView(TemplateView):
    def get_context_data(self, **kwargs):
        return kwargs

    def render(self, extra_context={}):
        context = self.get_context_data()
        context.update(extra_context)
        return self.render_to_response(context)

    def get(self, request):
        return self.render()



# -*- coding: utf-8 -*-
from django.forms.util import to_current_timezone

def tz_strftime(datetime, format):
    """Format a datetime in the current timezone."""
    corrected = to_current_timezone(datetime)
    return corrected.strftime(format)

def tz_localize(datetime):
    """Localize a datetime in the current timezone."""
    from django.utils.formats import localize
    corrected = to_current_timezone(datetime)
    return localize(corrected)



# -*- coding: utf-8 -*-
import os
from setuptools import setup

README = open(os.path.join(os.path.dirname(__file__), 'README.rst')).read()

# Allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-quintet',
    version='0.1',
    packages=['quintet'],
    include_package_data=True,
    license='BSD License',
    description='A collection of helpers for Django projects.',
    long_description=README,
    url='https://github.com/eliksir/django-quintet',
    author='Eliksir AS',
    author_email='code@e5r.no',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
)
